pub struct PsiInput {
pub date: Option<Date>,
pub pagination_token: Option<String>,
pub x_api_key: Option<String>,
}Expand description
https://api-open.data.gov.sg/v2/real-time/api/psi
-
Readings are provided for each major region in Singapore
-
Filter for a specific date by providing
datein query parameter (YYYY-MM-DD). -
example:
?date=2024-07-16 -
If
dateis not provided in query parameter, API will return the latest reading -
The
region_metadatafield in the response provides longitude/latitude information for the regions. You can use that to place the readings on a map. -
Unit of measure for readings is
PSI Value
Fields
date: Option<Date>SGT date for which to retrieve data (YYYY-MM-DD). Omit for latest.
pagination_token: Option<String>Pagination token for subsequent pages (only when date filter is used and more pages exist).
x_api_key: Option<String>Optional API key for higher rate limits.
Implementations