pub struct TwoHrForecastInput {
pub date: Option<Date>,
pub pagination_token: Option<String>,
pub x_api_key: Option<String>,
}Expand description
https://api-open.data.gov.sg/v2/real-time/api/two-hr-forecast
-
Forecasts are given for multiple areas in Singapore
-
Filter for specific date or date-time by providing
datein query parameter (YYYY-MM-DD or YYYY-MM-DDTHH:MM:SS). -
example:
?date=2024-07-16or?date=2024-07-16T23:59:00 -
Forecasts are valid for two hours, for example, the validity period of the forecast at 1pm is 1pm to 3pm
-
If
dateis not provided in query parameter, API will return the latest reading
Fields
date: Option<Date>SGT date for which to retrieve data (YYYY-MM-DD). Omit for latest.
pagination_token: Option<String>Pagination token for subsequent pages (only when date filter is used and more pages exist).
x_api_key: Option<String>Optional API key for higher rate limits.
Implementations