pub struct UvInput {
pub date: Option<Date>,
pub pagination_token: Option<String>,
pub x_api_key: Option<String>,
}Expand description
https://api-open.data.gov.sg/v2/real-time/api/uv
-
Updated between 7 AM and 7 PM everyday
-
The UV index value is averaged over the preceding hour
-
Filter for a specific date by providing
datein query parameter (YYYY-MM-DD). -
example:
?date=2024-07-16 -
If
dateis not provided in query parameter, API will return the latest reading -
Unit of measure for readings is
Ultraviolet Index
Fields
date: Option<Date>SGT date for which to retrieve data (YYYY-MM-DD). Omit for latest.
pagination_token: Option<String>Pagination token for subsequent pages (only when date filter is used and more pages exist).
x_api_key: Option<String>Optional API key for higher rate limits.
Implementations