WeatherSubApiInput

Struct WeatherSubApiInput 

pub struct WeatherSubApiInput {
    pub api: NeaWeatherSubApi,
    pub date: Option<Date>,
    pub pagination_token: Option<String>,
    pub x_api_key: Option<String>,
}
Unified weather sub-API endpoint.

  • ?api=lightning — Cloud-to-ground and cloud-to-cloud lightning strikes. Updated every ~2–3 minutes.

  • ?api=wbgt — Wet Bulb Globe Temperature heat stress readings. Updated every 15 minutes.

https://api-open.data.gov.sg/v2/real-time/api/weather?api=lightning

  • Updated multiple times throughout the day

  • Filter for a specific date by providing date in query parameter (YYYY-MM-DD).

  • example: ?date=2025-01-16

  • If date is not provided in query parameter, API will return the latest lightning observation

Fields

api: NeaWeatherSubApi

Sub-API selector (lightning or wbgt). Required.

date: Option<Date>

SGT date for which to retrieve data (YYYY-MM-DD). Omit for latest.

pagination_token: Option<String>

Pagination token for subsequent pages (only when date filter is used and more pages exist).

x_api_key: Option<String>

Optional API key for higher rate limits.

Implementations

Source

impl WeatherSubApiInput

pub fn new(api: NeaWeatherSubApi) -> Self

pub fn date(self, date: Date) -> Self

pub fn pagination_token(self, pagination_token: impl Into<String>) -> Self

pub fn x_api_key(self, x_api_key: impl Into<String>) -> Self